==> docx4j-openxml-objects-8.0.0-sources.jar: org/docx4j/dml/diagram/STConstraintRelationship.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_ConstraintRelationship.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_ConstraintRelationship">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token">
 *     &lt;enumeration value="self"/>
 *     &lt;enumeration value="ch"/>
 *     &lt;enumeration value="des"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_ConstraintRelationship")
@XmlEnum
public enum STConstraintRelationship {


    /**
     * Self
     * 
     */
    @XmlEnumValue("self")
    SELF("self"),

    /**
     * Child
     * 
     */
    @XmlEnumValue("ch")
    CH("ch"),

    /**
     * Descendant
     * 
     */
    @XmlEnumValue("des")
    DES("des");
    private final String value;

    STConstraintRelationship(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STConstraintRelationship fromValue(String v) {
        for (STConstraintRelationship c: STConstraintRelationship.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-8.2.4-sources.jar: org/docx4j/dml/diagram/STConstraintRelationship.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_ConstraintRelationship.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_ConstraintRelationship"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="self"/&gt;
 *     &lt;enumeration value="ch"/&gt;
 *     &lt;enumeration value="des"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_ConstraintRelationship")
@XmlEnum
public enum STConstraintRelationship {


    /**
     * Self
     * 
     */
    @XmlEnumValue("self")
    SELF("self"),

    /**
     * Child
     * 
     */
    @XmlEnumValue("ch")
    CH("ch"),

    /**
     * Descendant
     * 
     */
    @XmlEnumValue("des")
    DES("des");
    private final String value;

    STConstraintRelationship(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STConstraintRelationship fromValue(String v) {
        for (STConstraintRelationship c: STConstraintRelationship.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
